# Generated by Django 4.2.4 on 2023-08-28 21:16

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_tweets', '0002_remove_mediafile_upload'),
    ]

    operations = [
        migrations.CreateModel(
            name='MediaFileUpload',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('upload', models.BooleanField(default=False)),
                ('mediafile', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='django_tweets.mediafile')),
            ],
        ),
    ]
